@@ -1,9 +1,8 @@
 require 'test/unit'
-$:.unshift(File.expand_path(File.join(File.dirname(__FILE__),'..','lib')))
 require 'rubygems'
 require 'mechanize'
 require 'webrick/httputils'
-require File.join(File.dirname(__FILE__),'servlets')
+require 'servlets'
 
 BASE_DIR = File.dirname(__FILE__)
 
@@ -16,7 +15,7 @@ module MechTestHelper
     </body></html>
     END
     html_response = { 'content-type' => 'text/html' }
-    page = WWW::Mechanize::Page.new(  nil, html_response, html, 200, agent )
+    page = Mechanize::Page.new(  nil, html_response, html, 200, agent )
   end
 end
 
@@ -48,6 +47,8 @@ class Net::HTTP
     '/infinite_redirect'      => InfiniteRedirectTest,
     '/infinite_refresh'       => InfiniteRefreshTest,
     '/redirect'               => RedirectTest,
+    '/refresh_without_url'    => RefreshWithoutUrl,
+    '/refresh_with_empty_url' => RefreshWithEmptyUrl,
     '/digest_auth'            => DigestAuthServlet,
     '/verb'                   => VerbServlet,
   }
@@ -63,6 +64,8 @@ class Net::HTTP
     path = '/index.html' if path == '/'
 
     res = Response.new
+    res.query_params = url.query
+
     request.query = WEBrick::HTTPUtils.parse_query(url.query)
     request.cookies = WEBrick::Cookie.parse(request['Cookie'])
     if SERVLETS[path]
@@ -71,6 +74,7 @@ class Net::HTTP
           request.body = data.first
         else
           request.query = WEBrick::HTTPUtils.parse_query(data.first)
+          res.query_params = data.first
         end
       end
       SERVLETS[path].new({}).send("do_#{request.method}", request, res)
@@ -105,7 +109,8 @@ class Response
 
   attr_reader :code
   attr_accessor :body, :query, :cookies
-  
+  attr_accessor :query_params
+
   def code=(c)
     @code = c.to_s
   end
