@@ -1,8 +1,15 @@
-require File.expand_path(File.join(File.dirname(__FILE__), "helper"))
+require "helper"
 
 class FormsMechTest < Test::Unit::TestCase
   def setup
-    @agent = WWW::Mechanize.new
+    @agent = Mechanize.new
+  end
+
+  def test_post_with_blank_encoding
+    page = @agent.get("http://localhost/form_test.html")
+    form = page.form('post_form1')
+    form.page.encoding = nil
+    form.submit
   end
 
   def test_no_form_action
@@ -12,6 +19,17 @@ class FormsMechTest < Test::Unit::TestCase
     assert_match('/form_no_action.html?first=Aaron', page.uri.to_s)
   end
 
+  def test_submit_takes_arbirary_headers
+    page = @agent.get('http://localhost:2000/form_no_action.html')
+    assert form = page.forms.first
+    form.action = '/http_headers'
+    page = @agent.submit(form, nil, { 'foo' => 'bar' })
+    headers = Hash[*(
+      page.body.split("\n").map { |x| x.split('|') }.flatten
+    )]
+    assert_equal 'bar', headers['foo']
+  end
+
   # Test submitting form with two fields of the same name
   def test_post_multival
     page = @agent.get("http://localhost/form_multival.html")
@@ -72,6 +90,13 @@ class FormsMechTest < Test::Unit::TestCase
     assert_not_nil(page.link_with(:text => 'first:Patterson'))
   end
 
+  def test_post_with_non_strings
+    page = @agent.get("http://localhost/form_test.html")
+    page.form('post_form1') do |form|
+      form.first_name = 10
+    end.submit
+  end
+
   def test_post
     page = @agent.get("http://localhost/form_test.html")
     post_form = page.forms.find { |f| f.name == "post_form1" }
@@ -149,6 +174,21 @@ class FormsMechTest < Test::Unit::TestCase
     )
   end
 
+  def test_post_multipart
+    page = @agent.get("http://localhost/form_test.html")
+    post_form = page.forms.find { |f| f.name == "post_form4_multipart" }
+    assert_not_nil(post_form, "Post form is null")
+    assert_equal("post", post_form.method.downcase)
+    assert_equal("/form_post", post_form.action)
+    
+    assert_equal(1, post_form.fields.size)
+    assert_equal(1, post_form.buttons.size)
+    
+    page = @agent.submit(post_form, post_form.buttons.first)
+    
+    assert_not_nil(page)
+  end
+
   def test_select_box
     page = @agent.get("http://localhost/form_test.html")
     post_form = page.forms.find { |f| f.name == "post_form1" }
@@ -447,7 +487,6 @@ class FormsMechTest < Test::Unit::TestCase
     }.checked = true
     get_form.checkboxes.find { |f| f.name == "likes ham" }.checked = true
     page = @agent.submit(get_form, get_form.buttons.first)
-
     # Check that the submitted fields exist
     assert_equal(3, page.links.size, "Not enough links")
     assert_not_nil(
